@@ -1,8 +1,8 @@
 """Scaleway SDK for Python - Async"""
 
-import pkg_resources
+import importlib.metadata
 
-__version__: str = pkg_resources.get_distribution(__name__).version
+__version__: str = importlib.metadata.version(__name__)
 
 from scaleway_core.api import (
     API,
